summaryrefslogtreecommitdiffstats
path: root/kwin/lib
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 20:16:47 +0000
commit495d08bc2db58ee7fc4ea55a7158f2f61b82fc56 (patch)
treedaabcb652c07b9a17cad88ca50b63a2d91ead4a3 /kwin/lib
parent50001f1757f97510e80cb1990e2f2d5b00144c2a (diff)
downloadtdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.tar.gz
tdebase-495d08bc2db58ee7fc4ea55a7158f2f61b82fc56.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1211357 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kwin/lib')
-rw-r--r--kwin/lib/kcommondecoration.cpp132
-rw-r--r--kwin/lib/kcommondecoration.h30
-rw-r--r--kwin/lib/kdecoration.cpp8
-rw-r--r--kwin/lib/kdecoration.h42
-rw-r--r--kwin/lib/kdecoration_p.h2
-rw-r--r--kwin/lib/kdecoration_plugins_p.cpp2
-rw-r--r--kwin/lib/kdecorationfactory.cpp2
-rw-r--r--kwin/lib/kdecorationfactory.h4
8 files changed, 111 insertions, 111 deletions
diff --git a/kwin/lib/kdecoration.cpp b/kwin/lib/kdecoration.cpp
index 97c8965e9..22b3cd75c 100644
--- a/kwin/lib/kdecoration.cpp
+++ b/kwin/lib/kdecoration.cpp
@@ -68,7 +68,7 @@ void KDecoration::setMainWidget( TQWidget* w )
assert( w_ == NULL );
w_ = w;
w->setMouseTracking( true );
- widget()->resize( geometry().size());
+ widget()->resize( tqgeometry().size());
}
TQWidget* KDecoration::initialParentWidget() const
@@ -206,9 +206,9 @@ bool KDecoration::isPreview() const
return bridge_->isPreview();
}
-TQRect KDecoration::geometry() const
+TQRect KDecoration::tqgeometry() const
{
- return bridge_->geometry();
+ return bridge_->tqgeometry();
}
TQRect KDecoration::iconGeometry() const
@@ -388,7 +388,7 @@ const TQFont& KDecorationOptions::font(bool active, bool small) const
return(active ? d->activeFont : d->inactiveFont);
}
-const TQColorGroup& KDecorationOptions::colorGroup(ColorType type, bool active) const
+const TQColorGroup& KDecorationOptions::tqcolorGroup(ColorType type, bool active) const
{
int idx = type + (active ? 0 : NUM_COLORS);
if(d->cg[idx])
diff --git a/kwin/lib/kdecoration_p.h b/kwin/lib/kdecoration_p.h
index 58f386c9b..c3797831e 100644
--- a/kwin/lib/kdecoration_p.h
+++ b/kwin/lib/kdecoration_p.h
@@ -85,7 +85,7 @@ class KDecorationBridge : public KDecorationDefines
virtual void performWindowOperation( WindowOperation ) = 0;
virtual void setMask( const TQRegion&, int ) = 0;
virtual bool isPreview() const = 0;
- virtual TQRect geometry() const = 0;
+ virtual TQRect tqgeometry() const = 0;
virtual TQRect iconGeometry() const = 0;
virtual TQRegion unobscuredRegion( const TQRegion& r ) const = 0;
virtual TQWidget* workspaceWidget() const = 0;
diff --git a/kwin/lib/kdecoration_plugins_p.cpp b/kwin/lib/kdecoration_plugins_p.cpp
index 0490e4755..2e870eaf4 100644
--- a/kwin/lib/kdecoration_plugins_p.cpp
+++ b/kwin/lib/kdecoration_plugins_p.cpp
@@ -167,7 +167,7 @@ bool KDecorationPlugins::loadPlugin( TQString nameStr )
// For clients in kdeartwork
TQString catalogue = nameStr;
- catalogue.replace( "kwin3_", "kwin_" );
+ catalogue.tqreplace( "kwin3_", "kwin_" );
KGlobal::locale()->insertCatalogue( catalogue );
// For KCommonDecoration based clients
KGlobal::locale()->insertCatalogue( "kwin_lib" );
diff --git a/kwin/lib/kdecorationfactory.cpp b/kwin/lib/kdecorationfactory.cpp
index 7ad1aefbe..65fde37bc 100644
--- a/kwin/lib/kdecorationfactory.cpp
+++ b/kwin/lib/kdecorationfactory.cpp
@@ -58,7 +58,7 @@ TQValueList< KDecorationDefines::BorderSize > KDecorationFactory::borderSizes()
bool KDecorationFactory::exists( const KDecoration* deco ) const
{
- return _decorations.contains( const_cast< KDecoration* >( deco ));
+ return _decorations.tqcontains( const_cast< KDecoration* >( deco ));
}
void KDecorationFactory::addDecoration( KDecoration* deco )
diff --git a/kwin/lib/kdecorationfactory.h b/kwin/lib/kdecorationfactory.h
index 7396ad987..467a24f17 100644
--- a/kwin/lib/kdecorationfactory.h
+++ b/kwin/lib/kdecorationfactory.h
@@ -53,10 +53,10 @@ class KWIN_EXPORT KDecorationFactory
virtual KDecoration* createDecoration( KDecorationBridge* bridge ) = 0;
/**
* This function is called when the configuration settings changed.
- * The argument specifies what has changed, using the SettingXXX masks.
+ * The argument specifies what has changed, using the SettingXXX tqmasks.
* It should be determined whether the decorations need to be completely
* remade, in which case true should be returned, or whether only e.g.
- * a repaint will be sufficient, in which case false should be returned,
+ * a tqrepaint will be sufficient, in which case false should be returned,
* and resetDecorations() can be called to reset all decoration objects.
* Note that true should be returned only when really necessary.
*/
diff --git a/kwin/lib/kcommondecoration.cpp b/kwin/lib/kcommondecoration.cpp
index 87541ad60..a950a7ecb 100644
--- a/kwin/lib/kcommondecoration.cpp
+++ b/kwin/lib/kcommondecoration.cpp
@@ -73,7 +73,7 @@ bool KCommonDecoration::decorationBehaviour(DecorationBehaviour behaviour) const
return false;
}
-int KCommonDecoration::layoutMetric(LayoutMetric lm, bool, const KCommonDecorationButton *) const
+int KCommonDecoration::tqlayoutMetric(LayoutMetric lm, bool, const KCommonDecorationButton *) const
{
switch (lm) {
case LM_BorderLeft:
@@ -145,12 +145,12 @@ void KCommonDecoration::updateCaption()
void KCommonDecoration::borders( int& left, int& right, int& top, int& bottom ) const
{
- left = layoutMetric(LM_BorderLeft);
- right = layoutMetric(LM_BorderRight);
- bottom = layoutMetric(LM_BorderBottom);
- top = layoutMetric(LM_TitleHeight) +
- layoutMetric(LM_TitleEdgeTop) +
- layoutMetric(LM_TitleEdgeBottom);
+ left = tqlayoutMetric(LM_BorderLeft);
+ right = tqlayoutMetric(LM_BorderRight);
+ bottom = tqlayoutMetric(LM_BorderBottom);
+ top = tqlayoutMetric(LM_TitleHeight) +
+ tqlayoutMetric(LM_TitleEdgeTop) +
+ tqlayoutMetric(LM_TitleEdgeBottom);
updateLayout(); // TODO!! don't call everytime we are in ::borders
}
@@ -161,14 +161,14 @@ void KCommonDecoration::updateLayout() const
int r_x, r_y, r_x2, r_y2;
r.coords(&r_x, &r_y, &r_x2, &r_y2);
// layout preview widget
if (m_previewWidget) {
- const int borderLeft = layoutMetric(LM_BorderLeft);
- const int borderRight = layoutMetric(LM_BorderRight);
- const int borderBottom = layoutMetric(LM_BorderBottom);
- const int titleHeight = layoutMetric(LM_TitleHeight);
- const int titleEdgeTop = layoutMetric(LM_TitleEdgeTop);
- const int titleEdgeBottom = layoutMetric(LM_TitleEdgeBottom);
+ const int borderLeft = tqlayoutMetric(LM_BorderLeft);
+ const int borderRight = tqlayoutMetric(LM_BorderRight);
+ const int borderBottom = tqlayoutMetric(LM_BorderBottom);
+ const int titleHeight = tqlayoutMetric(LM_TitleHeight);
+ const int titleEdgeTop = tqlayoutMetric(LM_TitleEdgeTop);
+ const int titleEdgeBottom = tqlayoutMetric(LM_TitleEdgeBottom);
int left = r_x+borderLeft;
int top = r_y+titleEdgeTop+titleHeight+titleEdgeBottom;
@@ -182,28 +182,28 @@ void KCommonDecoration::updateLayout() const
// resize buttons...
for (int n=0; n<NumButtons; n++) {
if (m_button[n]) {
- TQSize newSize = TQSize(layoutMetric(LM_ButtonWidth, true, m_button[n]),
- layoutMetric(LM_ButtonHeight, true, m_button[n]) );
+ TQSize newSize = TQSize(tqlayoutMetric(LM_ButtonWidth, true, m_button[n]),
+ tqlayoutMetric(LM_ButtonHeight, true, m_button[n]) );
if (newSize != m_button[n]->size() )
m_button[n]->setSize(newSize);
}
}
- // layout buttons
- int y = r_y + layoutMetric(LM_TitleEdgeTop) + layoutMetric(LM_ButtonMarginTop);
+ // tqlayout buttons
+ int y = r_y + tqlayoutMetric(LM_TitleEdgeTop) + tqlayoutMetric(LM_ButtonMarginTop);
if (m_buttonsLeft.count() > 0) {
- const int buttonSpacing = layoutMetric(LM_ButtonSpacing);
- int x = r_x + layoutMetric(LM_TitleEdgeLeft);
+ const int buttonSpacing = tqlayoutMetric(LM_ButtonSpacing);
+ int x = r_x + tqlayoutMetric(LM_TitleEdgeLeft);
for (ButtonContainer::const_iterator it = m_buttonsLeft.begin(); it != m_buttonsLeft.end(); ++it) {
bool elementLayouted = false;
if (*it) {
if (!(*it)->isHidden() ) {
moveWidget(x,y, *it);
- x += layoutMetric(LM_ButtonWidth, true, ::qt_cast<KCommonDecorationButton*>(*it) );
+ x += tqlayoutMetric(LM_ButtonWidth, true, ::qt_cast<KCommonDecorationButton*>(*it) );
elementLayouted = true;
}
} else {
- x+= layoutMetric(LM_ExplicitButtonSpacer);
+ x+= tqlayoutMetric(LM_ExplicitButtonSpacer);
elementLayouted = true;
}
if (elementLayouted && it != m_buttonsLeft.end() )
@@ -212,20 +212,20 @@ void KCommonDecoration::updateLayout() const
}
if (m_buttonsRight.count() > 0) {
- const int titleEdgeRightLeft = r_x2-layoutMetric(LM_TitleEdgeRight)+1;
+ const int titleEdgeRightLeft = r_x2-tqlayoutMetric(LM_TitleEdgeRight)+1;
- const int buttonSpacing = layoutMetric(LM_ButtonSpacing);
+ const int buttonSpacing = tqlayoutMetric(LM_ButtonSpacing);
int x = titleEdgeRightLeft - buttonContainerWidth(m_buttonsRight);
for (ButtonContainer::const_iterator it = m_buttonsRight.begin(); it != m_buttonsRight.end(); ++it) {
bool elementLayouted = false;
if (*it) {
if (!(*it)->isHidden() ) {
moveWidget(x,y, *it);
- x += layoutMetric(LM_ButtonWidth, true, ::qt_cast<KCommonDecorationButton*>(*it) );;
+ x += tqlayoutMetric(LM_ButtonWidth, true, ::qt_cast<KCommonDecorationButton*>(*it) );;
elementLayouted = true;
}
} else {
- x += layoutMetric(LM_ExplicitButtonSpacer);
+ x += tqlayoutMetric(LM_ExplicitButtonSpacer);
elementLayouted = true;
}
if (elementLayouted && it != m_buttonsRight.end() )
@@ -277,8 +277,8 @@ void KCommonDecoration::resetLayout()
const int minTitleBarWidth = 35;
btnHideMinWidth = buttonContainerWidth(m_buttonsLeft,true) + buttonContainerWidth(m_buttonsRight,true) +
- layoutMetric(LM_TitleEdgeLeft,false) + layoutMetric(LM_TitleEdgeRight,false) +
- layoutMetric(LM_TitleBorderLeft,false) + layoutMetric(LM_TitleBorderRight,false) +
+ tqlayoutMetric(LM_TitleEdgeLeft,false) + tqlayoutMetric(LM_TitleEdgeRight,false) +
+ tqlayoutMetric(LM_TitleBorderLeft,false) + tqlayoutMetric(LM_TitleBorderRight,false) +
minTitleBarWidth;
btnHideLastWidth = 0;
}
@@ -295,7 +295,7 @@ int KCommonDecoration::buttonsRightWidth() const
int KCommonDecoration::buttonContainerWidth(const ButtonContainer &btnContainer, bool countHidden) const
{
- int explicitSpacer = layoutMetric(LM_ExplicitButtonSpacer);
+ int explicitSpacer = tqlayoutMetric(LM_ExplicitButtonSpacer);
int shownElementsCount = 0;
@@ -311,7 +311,7 @@ int KCommonDecoration::buttonContainerWidth(const ButtonContainer &btnContainer,
++shownElementsCount;
}
}
- w += layoutMetric(LM_ButtonSpacing)*(shownElementsCount-1);
+ w += tqlayoutMetric(LM_ButtonSpacing)*(shownElementsCount-1);
return w;
}
@@ -437,7 +437,7 @@ void KCommonDecoration::addButtons(ButtonContainer &btnContainer, const TQString
if (btn) {
btn->setLeft(isLeft);
- btn->setSize(TQSize(layoutMetric(LM_ButtonWidth, true, btn),layoutMetric(LM_ButtonHeight, true, btn)) );
+ btn->setSize(TQSize(tqlayoutMetric(LM_ButtonWidth, true, btn),tqlayoutMetric(LM_ButtonHeight, true, btn)) );
btn->show();
btnContainer.append(btn);
}
@@ -497,15 +497,15 @@ void KCommonDecoration::resize( const TQSize& s )
widget()->resize( s );
}
-TQSize KCommonDecoration::minimumSize() const
+TQSize KCommonDecoration::tqminimumSize() const
{
- const int minWidth = QMAX(layoutMetric(LM_TitleEdgeLeft), layoutMetric(LM_BorderLeft))
- +QMAX(layoutMetric(LM_TitleEdgeRight), layoutMetric(LM_BorderRight))
- +layoutMetric(LM_TitleBorderLeft)+layoutMetric(LM_TitleBorderRight);
+ const int minWidth = QMAX(tqlayoutMetric(LM_TitleEdgeLeft), tqlayoutMetric(LM_BorderLeft))
+ +QMAX(tqlayoutMetric(LM_TitleEdgeRight), tqlayoutMetric(LM_BorderRight))
+ +tqlayoutMetric(LM_TitleBorderLeft)+tqlayoutMetric(LM_TitleBorderRight);
return TQSize(minWidth,
- layoutMetric(LM_TitleEdgeTop)+layoutMetric(LM_TitleHeight)
- +layoutMetric(LM_TitleEdgeBottom)
- +layoutMetric(LM_BorderBottom) );
+ tqlayoutMetric(LM_TitleEdgeTop)+tqlayoutMetric(LM_TitleHeight)
+ +tqlayoutMetric(LM_TitleEdgeBottom)
+ +tqlayoutMetric(LM_BorderBottom) );
}
void KCommonDecoration::maximizeChange()
@@ -659,7 +659,7 @@ void KCommonDecoration::resizeEvent(TQResizeEvent */*e*/)
updateWindowShape();
// FIXME: don't update() here! this would result in two paintEvent()s
- // because there is already "something" else triggering the repaint...
+ // because there is already "something" else triggering the tqrepaint...
// widget()->update();
}
@@ -688,7 +688,7 @@ void KCommonDecoration::mouseDoubleClickEvent(TQMouseEvent *e)
if( e->button() != LeftButton )
return;
- int tb = layoutMetric(LM_TitleEdgeTop)+layoutMetric(LM_TitleHeight)+layoutMetric(LM_TitleEdgeBottom);
+ int tb = tqlayoutMetric(LM_TitleEdgeTop)+tqlayoutMetric(LM_TitleHeight)+tqlayoutMetric(LM_TitleEdgeBottom);
// when shaded, react on double clicks everywhere to make it easier to unshade. otherwise
// react only on double clicks in the title bar region...
if (isSetShade() || e->pos().y() <= tb )
@@ -697,14 +697,14 @@ void KCommonDecoration::mouseDoubleClickEvent(TQMouseEvent *e)
void KCommonDecoration::wheelEvent(TQWheelEvent *e)
{
- int tb = layoutMetric(LM_TitleEdgeTop)+layoutMetric(LM_TitleHeight)+layoutMetric(LM_TitleEdgeBottom);
+ int tb = tqlayoutMetric(LM_TitleEdgeTop)+tqlayoutMetric(LM_TitleHeight)+tqlayoutMetric(LM_TitleEdgeBottom);
if (isSetShade() || e->pos().y() <= tb )
titlebarMouseWheelOperation( e->delta());
}
KCommonDecoration::Position KCommonDecoration::mousePosition(const TQPoint &point) const
{
- const int corner = 18+3*layoutMetric(LM_BorderBottom, false)/2;
+ const int corner = 18+3*tqlayoutMetric(LM_BorderBottom, false)/2;
Position pos = PositionCenter;
TQRect r = widget()->rect();
@@ -712,14 +712,14 @@ KCommonDecoration::Position KCommonDecoration::mousePosition(const TQPoint &poin
r.coords(&r_x, &r_y, &r_x2, &r_y2);
int p_x = point.x();
int p_y = point.y();
- const int borderLeft = layoutMetric(LM_BorderLeft);
-// const int borderRight = layoutMetric(LM_BorderRight);
- const int borderBottom = layoutMetric(LM_BorderBottom);
- const int titleHeight = layoutMetric(LM_TitleHeight);
- const int titleEdgeTop = layoutMetric(LM_TitleEdgeTop);
- const int titleEdgeBottom = layoutMetric(LM_TitleEdgeBottom);
- const int titleEdgeLeft = layoutMetric(LM_TitleEdgeLeft);
- const int titleEdgeRight = layoutMetric(LM_TitleEdgeRight);
+ const int borderLeft = tqlayoutMetric(LM_BorderLeft);
+// const int borderRight = tqlayoutMetric(LM_BorderRight);
+ const int borderBottom = tqlayoutMetric(LM_BorderBottom);
+ const int titleHeight = tqlayoutMetric(LM_TitleHeight);
+ const int titleEdgeTop = tqlayoutMetric(LM_TitleEdgeTop);
+ const int titleEdgeBottom = tqlayoutMetric(LM_TitleEdgeBottom);
+ const int titleEdgeLeft = tqlayoutMetric(LM_TitleEdgeLeft);
+ const int titleEdgeRight = tqlayoutMetric(LM_TitleEdgeRight);
const int borderBottomTop = r_y2-borderBottom+1;
const int borderLeftRight = r_x+borderLeft-1;
@@ -769,7 +769,7 @@ KCommonDecoration::Position KCommonDecoration::mousePosition(const TQPoint &poin
void KCommonDecoration::updateWindowShape()
{
// don't mask the widget...
if (!decorationBehaviour(DB_WindowMask) )
return;
@@ -783,7 +783,7 @@ void KCommonDecoration::updateWindowShape()
for(int screen=0; screen < desktop->numScreens(); ++screen)
{
TQRect fullscreen(desktop->screenGeometry(screen));
- TQRect window = geometry();
+ TQRect window = tqgeometry();
if(window.topLeft() == fullscreen.topLeft() ) tl = false;
if(window.topRight() == fullscreen.topRight() ) tr = false;
@@ -791,30 +791,30 @@ void KCommonDecoration::updateWindowShape()
if(window.bottomRight()== fullscreen.bottomRight() ) br = false;
}
- TQRegion mask(0, 0, w, h);
+ TQRegion tqmask(0, 0, w, h);
// Remove top-left corner.
if(tl)
{
- mask -= cornerShape(WC_TopLeft);
+ tqmask -= cornerShape(WC_TopLeft);
}
// Remove top-right corner.
if(tr)
{
- mask -= cornerShape(WC_TopRight);
+ tqmask -= cornerShape(WC_TopRight);
}
// Remove top-left corner.
if(bl)
{
- mask -= cornerShape(WC_BottomLeft);
+ tqmask -= cornerShape(WC_BottomLeft);
}
// Remove top-right corner.
if(br)
{
- mask -= cornerShape(WC_BottomRight);
+ tqmask -= cornerShape(WC_BottomRight);
}
- setMask( mask );
+ setMask( tqmask );
}
bool KCommonDecoration::eventFilter( TQObject* o, TQEvent* e )
@@ -857,13 +857,13 @@ TQRect KCommonDecoration::titleRect() const
{
int r_x, r_y, r_x2, r_y2;
widget()->rect().coords(&r_x, &r_y, &r_x2, &r_y2);
- const int titleEdgeLeft = layoutMetric(LM_TitleEdgeLeft);
- const int titleEdgeTop = layoutMetric(LM_TitleEdgeTop);
- const int titleEdgeRight = layoutMetric(LM_TitleEdgeRight);
- const int titleEdgeBottom = layoutMetric(LM_TitleEdgeBottom);
- const int titleBorderLeft = layoutMetric(LM_TitleBorderLeft);
- const int titleBorderRight = layoutMetric(LM_TitleBorderRight);
- const int ttlHeight = layoutMetric(LM_TitleHeight);
+ const int titleEdgeLeft = tqlayoutMetric(LM_TitleEdgeLeft);
+ const int titleEdgeTop = tqlayoutMetric(LM_TitleEdgeTop);
+ const int titleEdgeRight = tqlayoutMetric(LM_TitleEdgeRight);
+ const int titleEdgeBottom = tqlayoutMetric(LM_TitleEdgeBottom);
+ const int titleBorderLeft = tqlayoutMetric(LM_TitleBorderLeft);
+ const int titleBorderRight = tqlayoutMetric(LM_TitleBorderRight);
+ const int ttlHeight = tqlayoutMetric(LM_TitleHeight);
const int titleEdgeBottomBottom = r_y+titleEdgeTop+ttlHeight+titleEdgeBottom-1;
return TQRect(r_x+titleEdgeLeft+buttonsLeftWidth()+titleBorderLeft, r_y+titleEdgeTop,
r_x2-titleEdgeRight-buttonsRightWidth()-titleBorderRight-(r_x+titleEdgeLeft+buttonsLeftWidth()+titleBorderLeft),
@@ -921,7 +921,7 @@ void KCommonDecorationButton::setSize(const TQSize &s)
}
}
-TQSize KCommonDecorationButton::sizeHint() const
+TQSize KCommonDecorationButton::tqsizeHint() const
{
return m_size;
}
@@ -161,14 +161,14 @@ void KCommonDecoration::updateLayout() const
int r_x, r_y, r_x2, r_y2;
r.coords(&r_x, &r_y, &r_x2, &r_y2);
- // layout preview widget
+ // tqlayout preview widget
if (m_previewWidget) {
@@ -769,7 +769,7 @@ KCommonDecoration::Position KCommonDecoration::mousePosition(const TQPoint &poin
void KCommonDecoration::updateWindowShape()
{
- // don't mask the widget...
+ // don't tqmask the widget...
if (!decorationBehaviour(DB_WindowMask) )
return;
diff --git a/kwin/lib/kcommondecoration.h b/kwin/lib/kcommondecoration.h
index f515a7da7..64e852e77 100644
--- a/kwin/lib/kcommondecoration.h
+++ b/kwin/lib/kcommondecoration.h
@@ -54,7 +54,7 @@ class KCommonDecorationPrivate;
/**
* This class eases development of decorations by implementing parts of KDecoration
* which are error prone and common for most decorations.
* It takes care of the window layout, button/action handling, and window mask creation.
*/
class KWIN_EXPORT KCommonDecoration : public KDecoration
{
@@ -65,7 +65,7 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
virtual ~KCommonDecoration();
/**
* Used to calculate the decoration layout. The basic layout looks like this:
*
* Window:
* _______________________________________________________________
@@ -95,7 +95,7 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
* | button | spacing | button | spacing | explicit spacer | spacing | ... | spacing | button |
* |________|_________|________|_________|_________________|_________|________|_________|________|
*
- * @see layoutMetric()
+ * @see tqlayoutMetric()
*/
enum LayoutMetric
{
@@ -119,7 +119,7 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
enum DecorationBehaviour
{
DB_MenuClose, ///< Close window on double clicking the menu
- DB_WindowMask, ///< Set a mask on the window
+ DB_WindowMask, ///< Set a tqmask on the window
DB_ButtonHide ///< Hide buttons when there is not enough space in the titlebar
};
@@ -155,13 +155,13 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
virtual bool decorationBehaviour(DecorationBehaviour behaviour) const;
/**
* This controls the layout of the decoration in various ways. It is
* possible to have a different layout for different window states.
* @param lm The layout element.
* @param respectWindowState Whether window states should be taken into account or a "default" state should be assumed.
* @param button For LM_ButtonWidth and LM_ButtonHeight, the button.
*/
- virtual int layoutMetric(LayoutMetric lm, bool respectWindowState = true, const KCommonDecorationButton *button = 0) const;
+ virtual int tqlayoutMetric(LayoutMetric lm, bool respectWindowState = true, const KCommonDecorationButton *button = 0) const;
/**
* Create a new title bar button. KCommonDecoration takes care of memory management.
@@ -170,14 +170,14 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
virtual KCommonDecorationButton *createButton(ButtonType type) = 0;
/**
* @return the mask for the specific window corner.
*/
virtual TQRegion cornerShape(WindowCorner corner);
/**
* This updates the window mask using the information provided by
* cornerShape(). Edges which are aligned to screen corners are not
- * shaped for better usability (remember to paint these areas in paintEvent(), too).
+ * tqshaped for better usability (remember to paint these areas in paintEvent(), too).
* You normally don't want/need to reimplement updateWindowShape().
* @see cornerShape()
*/
@@ -202,7 +202,7 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
*/
void updateLayout() const;
/**
- * Makes sure all buttons are repainted.
+ * Makes sure all buttons are tqrepainted.
*/
void updateButtons() const;
/**
@@ -223,7 +223,7 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
public:
/**
* Handles widget and layout creation, call the base implementation when subclassing this member.
*/
virtual void init();
/**
@@ -233,7 +233,7 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
virtual void borders( int& left, int& right, int& top, int& bottom ) const;
virtual void show();
virtual void resize(const TQSize& s);
- virtual TQSize minimumSize() const;
+ virtual TQSize tqminimumSize() const;
virtual void maximizeChange();
virtual void desktopChange();
virtual void shadeChange();
@@ -343,7 +343,7 @@ class KWIN_EXPORT KCommonDecorationButton : public QButton
*/
ButtonState lastMousePress() const { return m_lastMouse; }
- TQSize sizeHint() const;
+ TQSize tqsizeHint() const;
protected:
void setToggleButton(bool toggle);
@@ -54,7 +54,7 @@ class KCommonDecorationPrivate;
* This class eases development of decorations by implementing parts of KDecoration
* which are error prone and common for most decorations.
- * It takes care of the window layout, button/action handling, and window mask creation.
+ * It takes care of the window tqlayout, button/action handling, and window tqmask creation.
*/
class KWIN_EXPORT KCommonDecoration : public KDecoration
@@ -65,7 +65,7 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
virtual ~KCommonDecoration();
/**
- * Used to calculate the decoration layout. The basic layout looks like this:
+ * Used to calculate the decoration tqlayout. The basic tqlayout looks like this:
*
* Window:
@@ -155,13 +155,13 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
virtual bool decorationBehaviour(DecorationBehaviour behaviour) const;
/**
- * This controls the layout of the decoration in various ways. It is
- * possible to have a different layout for different window states.
- * @param lm The layout element.
+ * This controls the tqlayout of the decoration in various ways. It is
+ * possible to have a different tqlayout for different window states.
+ * @param lm The tqlayout element.
* @param respectWindowState Whether window states should be taken into account or a "default" state should be assumed.
* @param button For LM_ButtonWidth and LM_ButtonHeight, the button.
@@ -170,14 +170,14 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
virtual KCommonDecorationButton *createButton(ButtonType type) = 0;
/**
- * @return the mask for the specific window corner.
+ * @return the tqmask for the specific window corner.
*/
virtual TQRegion cornerShape(WindowCorner corner);
@@ -170,14 +170,14 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
virtual TQRegion cornerShape(WindowCorner corner);
/**
- * This updates the window mask using the information provided by
+ * This updates the window tqmask using the information provided by
* cornerShape(). Edges which are aligned to screen corners are not
@@ -223,7 +223,7 @@ class KWIN_EXPORT KCommonDecoration : public KDecoration
public:
/**
- * Handles widget and layout creation, call the base implementation when subclassing this member.
+ * Handles widget and tqlayout creation, call the base implementation when subclassing this member.
*/
virtual void init();
diff --git a/kwin/lib/kdecoration.h b/kwin/lib/kdecoration.h
index f41f19041..89cdf95a5 100644
--- a/kwin/lib/kdecoration.h
+++ b/kwin/lib/kdecoration.h
@@ -127,7 +127,7 @@ public:
SettingDecoration = 1 << 0, ///< The decoration was changed
SettingColors = 1 << 1, ///< The color palette was changed
SettingFont = 1 << 2, ///< The titlebar font was changed
- SettingButtons = 1 << 3, ///< The button layout was changed
+ SettingButtons = 1 << 3, ///< The button tqlayout was changed
SettingTooltips = 1 << 4, ///< The tooltip setting was changed
SettingBorder = 1 << 5 ///< The border size setting was changed
};
@@ -205,7 +205,7 @@ public:
* @param type The requested color type.
* @param active Whether to return the color for active or inactive windows.
*/
- const TQColorGroup& colorGroup(ColorType type, bool active=true) const;
+ const TQColorGroup& tqcolorGroup(ColorType type, bool active=true) const;
/**
* Returns the active or inactive decoration font.
* The changed flags for this setting is SettingFont.
@@ -291,7 +291,7 @@ public:
/**
* @internal
*/
- virtual unsigned long updateSettings() = 0; // returns SettingXYZ mask
+ virtual unsigned long updateSettings() = 0; // returns SettingXYZ tqmask
protected:
/**
@@ -412,7 +412,7 @@ class KWIN_EXPORT KDecoration
bool isResizable() const;
/**
* This function returns the window type of the decorated window.
- * The argument to this function is a mask of all window types
+ * The argument to this function is a tqmask of all window types
* the decoration knows about (as the list of valid window types
* is extended over time, and fallback types are specified in order
* to support older code). For a description of all window types,
@@ -451,7 +451,7 @@ class KWIN_EXPORT KDecoration
*
* \note Decorations that enable a double-click operation for the menu
* button must ensure to call \a showWindowMenu() with the \a pos
* rectangle set to the menu button geometry.
* IMPORTANT: As a result of this function, the decoration object that
* called it may be destroyed after the function returns. This means
* that the decoration object must either return immediately after
@@ -481,15 +481,15 @@ class KWIN_EXPORT KDecoration
void performWindowOperation( WindowOperation op );
/**
* If the decoration is non-rectangular, this function needs to be called
- * to set the shape of the decoration.
+ * to set the tqshape of the decoration.
*
- * @param reg The shape of the decoration.
+ * @param reg The tqshape of the decoration.
* @param mode The X11 values Unsorted, YSorted, YXSorted and YXBanded that specify
* the sorting of the rectangles, default value is Unsorted.
*/
void setMask( const TQRegion& reg, int mode = 0 );
/**
- * This convenience function resets the shape mask.
+ * This convenience function resets the tqshape tqmask.
*/
void clearMask(); // convenience
/**
@@ -499,13 +499,13 @@ class KWIN_EXPORT KDecoration
*/
bool isPreview() const;
/**
* Returns the geometry of the decoration.
*/
- TQRect geometry() const;
+ TQRect tqgeometry() const;
/**
* Returns the icon geometry for the window, i.e. the geometry of the taskbar
* entry. This is used mainly for window minimize animations. Note that
* the geometry may be null.
*/
TQRect iconGeometry() const;
/**
@@ -573,13 +573,13 @@ class KWIN_EXPORT KDecoration
* whether it's shaded. Decorations often turn off their bottom border when the
* window is shaded, and turn off their left/right/bottom borders when
* the window is maximized and moving and resizing of maximized windows is disabled.
- * This function mustn't do any repaints or resizes. Also, if the sizes returned
+ * This function mustn't do any tqrepaints or resizes. Also, if the sizes returned
* by this function don't match the real values, this may result in drawing errors
* or other problems.
*
* @see KDecorationOptions::moveResizeMaximizedWindows()
*/
- // mustn't do any repaints, resizes or anything like that
+ // mustn't do any tqrepaints, resizes or anything like that
virtual void borders( int& left, int& right, int& top, int& bottom ) const = 0;
/**
* This method is called by kwin when the style should resize the decoration window.
@@ -594,7 +594,7 @@ class KWIN_EXPORT KDecoration
* Note that the returned size shouldn't be too large, because it will be
* used to keep the decorated window at least as large.
*/
- virtual TQSize minimumSize() const = 0;
+ virtual TQSize tqminimumSize() const = 0;
/**
* This function is called whenever the window either becomes or stops being active.
* Use isActive() to find out the current state.
@@ -647,10 +647,10 @@ class KWIN_EXPORT KDecoration
* you should compensate for the 2 pixels that would make the window
* look larger.
*
* @param geom The geometry at this the bound should be drawn
* @param clear @a true if the bound should be cleared
*
- * @see workspaceWidget() and geometry().
+ * @see workspaceWidget() and tqgeometry().
*/
virtual bool drawbound( const TQRect& geom, bool clear );
/**
@@ -661,7 +661,7 @@ class KWIN_EXPORT KDecoration
* @a False should be returned if the default implementation should be used.
* Note that you should not use this function to force disabling of the animation.
*
- * @see workspaceWidget(), geometry() and helperShowHide().
+ * @see workspaceWidget(), tqgeometry() and helperShowHide().
*/
virtual bool animateMinimize( bool minimize );
/**
@@ -673,7 +673,7 @@ class KWIN_EXPORT KDecoration
* This function is called to reset the decoration on settings changes.
* It is usually invoked by calling KDecorationFactory::resetDecorations().
*
- * @param changed Specifies which settings were changed, given by the SettingXXX masks
+ * @param changed Specifies which settings were changed, given by the SettingXXX tqmasks
*/
virtual void reset( unsigned long changed );
@@ -877,12 +877,12 @@ inline bool KDecoration::isOnAllDesktops() const
inline int KDecoration::width() const
{
- return geometry().width();
+ return tqgeometry().width();
}
inline int KDecoration::height() const
{
- return geometry().height();
+ return tqgeometry().height();
}
#endif
@@ -451,7 +451,7 @@ class KWIN_EXPORT KDecoration
* \note Decorations that enable a double-click operation for the menu
* button must ensure to call \a showWindowMenu() with the \a pos
- * rectangle set to the menu button geometry.
+ * rectangle set to the menu button tqgeometry.
* IMPORTANT: As a result of this function, the decoration object that
* called it may be destroyed after the function returns. This means
@@ -499,13 +499,13 @@ class KWIN_EXPORT KDecoration
bool isPreview() const;
/**
- * Returns the geometry of the decoration.
+ * Returns the tqgeometry of the decoration.
*/
@@ -499,13 +499,13 @@ class KWIN_EXPORT KDecoration
/**
- * Returns the icon geometry for the window, i.e. the geometry of the taskbar
+ * Returns the icon tqgeometry for the window, i.e. the tqgeometry of the taskbar
* entry. This is used mainly for window minimize animations. Note that
@@ -499,13 +499,13 @@ class KWIN_EXPORT KDecoration
* entry. This is used mainly for window minimize animations. Note that
- * the geometry may be null.
+ * the tqgeometry may be null.
*/
TQRect iconGeometry() const;
@@ -647,10 +647,10 @@ class KWIN_EXPORT KDecoration
* look larger.
*
- * @param geom The geometry at this the bound should be drawn
+ * @param geom The tqgeometry at this the bound should be drawn
* @param clear @a true if the bound should be cleared
*